@@ -21,7 +21,7 @@
 #ifndef __FOLDER_TO_XML_HEADER_
 #define __FOLDER_TO_XML_HEADER_
 
-gboolean folder_to_xml(gchar *folder,gchar *save_filename);
+gboolean folder_to_xml(gchar *folder,gchar *save_filename,int max_depth);
 
 
 #endif /*__FOLDER_TO_XML_HEADER_*/
