@@ -27,6 +27,7 @@
 #include "scite_utils.h"
 #include "about.h"
 #include "file_utils.h"
+#include "string_utils.h"
 
 #include <stdlib.h>
 
@@ -50,13 +51,14 @@ int main(int argc, char *argv[])
 	int returnCode = -1;
 	GError *err = NULL;
 	
+	parse_cmd_options(argc,argv);
+	
 	// Init gtk
 	gtk_init(&argc, &argv);
 	
 	g_thread_init(NULL);
 	
 	init_file_utils();
-	parse_cmd_options(argc,argv);
 	
 	// Init sciteproj prefs
 	if (!init_prefs(&err)) {
@@ -195,10 +197,14 @@ static void parse_cmd_options(int argc,char *argv[])
 			
 			g_print("\n\n");
 			g_print("%s\n\n", "Options can be one of the following:");
-			g_print("%s\n", "  --help               display this help and exit");
-			g_print("%s\n", "  --scite [filename]   set a filename for the instance of SciTE to open");			
+			g_print("%s\n", "  --help                            display this help and exit");
+			g_print("%s\n", "  --version                         show version of sciteproj and exit");
+			g_print("%s\n", "  --scite FILENAME                  set a filename for the instance of SciTE to open");			
+			g_print("%s\n", "  --generate FILENAME [MAX_DEPTH]   generate a sciteproj project file with name FILENAME,");
+			g_print("%s\n", "                                      recursively from current folder contents, at most");
+			g_print("%s\n", "                                      MAX_DEPTH folders down in the hierarchy");
 			g_print("\n");
-			exit(1);
+			exit(EXIT_SUCCESS);
 			
 		} else if (!strncmp(argv[i],"--scite",7)) {
 			const gchar *p = argv[i + 1];
@@ -217,7 +223,42 @@ static void parse_cmd_options(int argc,char *argv[])
 		} else if (!strncmp(argv[i],"--version",9)) {
 			
 			show_version();
-			exit(1);
+			exit(EXIT_SUCCESS);
+		} else if (!strncmp(argv[i],"--generate",10)) {
+			
+			if ((argc!=3) && (argc!=4)) {
+				
+				printf("\nThe syntax for that command is:\n\n");
+				printf("sciteproj --generate FILENAME [MAX_DEPTH]\n\n");
+				
+				exit(EXIT_FAILURE);
+			}
+			
+			//gchar *folder=argv[2];
+			gchar *filename=argv[2];
+			int max_depth=4;
+
+			if (argc==5) {
+				gchar *max_depth_s=argv[3];
+				
+				if (!is_integer(max_depth_s)) {
+					printf("Expected an integer as max_depth...\n\n");
+					exit(EXIT_FAILURE);
+				} else {
+					max_depth=atoi(max_depth_s);
+				}
+			}
+			
+			//gboolean result=folder_to_xml(folder,filename,max_depth);
+			gboolean result=folder_to_xml(".",filename,max_depth);
+			
+			if (result) {
+				printf("Generated '%s' successfully!\n\n",filename);
+			} else {
+				exit(EXIT_FAILURE);
+			}
+			
+			exit(EXIT_SUCCESS);
 		} else {
 			
 			indata_left=argv[i];
