@@ -283,9 +283,6 @@ gboolean launch_scite(gchar *instring,GError **err)
 	gboolean resultCode = FALSE;
 	gchar* ipcDirectorName = (gchar*)"ipc.director.name";
 	gchar* ipcSciteName = (gchar*)"ipc.scite.name";
-	pid_t ourPID = 0;
-	pid_t childPID = 0;
-	int errCode;
 	GtkWidget* dialog = NULL;
 	int childPipePair[2] = { 0, 0 };
 	
@@ -308,9 +305,6 @@ gboolean launch_scite(gchar *instring,GError **err)
 	static unsigned long usecsDelta = 100000;
 	static unsigned long usecsDialogDelay;
 	
-	gulong usecs = 0;
-
-	
 	// Clean up anything open from previous attempts/activity
 	
 	shutdown_pipes();
@@ -321,6 +315,10 @@ gboolean launch_scite(gchar *instring,GError **err)
 	if (scite_exists) {
 	
 	// We need our process id for use in forming the named pipe filenames
+		pid_t ourPID = 0;
+		pid_t childPID = 0;
+		gulong usecs=0;
+		int errCode;
 	
 	ourPID = getpid();
 	
@@ -609,8 +607,6 @@ gboolean send_scite_command(gchar *command, GError **err)
 #endif
 	
 	gboolean resultCode = FALSE;
-	int byteCount;
-	int errCode;
 	int commandLength = strlen(command);
 	
 	
@@ -623,16 +619,14 @@ gboolean send_scite_command(gchar *command, GError **err)
 	
 	// Send the command over the request pipe....
 	
-	if ((byteCount = write(sRequestPipeFD, command, commandLength)) < commandLength) {
-		errCode = errno;
+	if ((write(sRequestPipeFD, command, commandLength)) < commandLength) {
+		int errCode = errno;
 		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not send command to Scite, write(\"%s\") failed, errno = %d = %s", __func__, command, errCode, strerror(errCode));
 		goto EXITPOINT;
 	}
 	
-	
 	resultCode = TRUE;
 	
-	
 EXITPOINT:
 	
 	return resultCode;
