@@ -147,7 +147,7 @@ gboolean abs_path_to_relative_path(const gchar *absPath, gchar **relativePath, c
 	
 EXITPOINT:
 	
-	if (workingDir) free(workingDir);
+	free(workingDir);
 	if (localBasePath) g_free(localBasePath);
 	
 	return finalResult;
@@ -187,11 +187,7 @@ gboolean relative_path_to_abs_path(gchar *relativePath, gchar **absPath, const g
 	
 	// On linux check if first character is '/', and on windows check for something 
 	// like "C:" in the beginning of the string
-#ifdef _WIN32
-	if (relativePath[1]==':') {
-#else	
 	if (relativePath[0] == G_DIR_SEPARATOR) {
-#endif	
 		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Specified path, '%s', is absolute", __func__ , relativePath);
 		g_print("Separator at birth.\n");
 		goto EXITPOINT;
@@ -424,5 +420,21 @@ char *remove_newline( char *s )
 	 
 }
 
+/**
+ * returns true if a gchar is an integer
+ *	(Very limited functionality at the moment)
+ */
+gboolean is_integer(gchar *string)
+{
+	int co;
+	
+	for (co=0;co<(int)strlen(string);co++) {
+		if (string[co]<'0' || string[co]>'9') {
+			return FALSE;
+		}
+	}
+	
+	return TRUE;
+}
 
 
